@@ -34,9 +34,9 @@ def get_changelog_version(project_root_path):
     return version_info
 
 
-#@pytest.mark.skipif(os.environ.get('GITHUB_ACTIONS') == 'true',
-#                    reason=("Clone depth of 1 doesn't allow last "
-#                           "release number to be detected."))
+@pytest.mark.skipif(os.environ.get('GITHUB_ACTIONS') == 'true',
+                    reason=("Clone depth of 1 doesn't allow last "
+                           "release number to be detected."))
 def test_version(project_root_path):
     version_info = version.parse(sfrmaker.__version__)
     readme_version = get_readme_version(project_root_path)
